aboutsummaryrefslogtreecommitdiff
path: root/drivers/staging/hv/Connection.c
diff options
context:
space:
mode:
authorGreg Kroah-Hartman <gregkh@suse.de>2009-07-14 15:09:36 -0700
committerGreg Kroah-Hartman <gregkh@suse.de>2009-09-15 12:01:46 -0700
commit4d64311468a90d4ab1e83c62d63b27da598b73ea (patch)
tree958df2af78911f7f6d66040f7fbcd965a1cbd4b6 /drivers/staging/hv/Connection.c
parent5cd508bc3ac032343e6853cd5712ac392942fb2c (diff)
Staging: hv: remove UINT32 and INT32 typedefs
The UINT32 and INT32 typedefs are now removed from the Hyper-V driver code. Cc: Hank Janssen <hjanssen@microsoft.com> Cc: Haiyang Zhang <haiyangz@microsoft.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/hv/Connection.c')
-rw-r--r--drivers/staging/hv/Connection.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/drivers/staging/hv/Connection.c b/drivers/staging/hv/Connection.c
index f3e1360564b..0e9f0d71925 100644
--- a/drivers/staging/hv/Connection.c
+++ b/drivers/staging/hv/Connection.c
@@ -253,7 +253,7 @@ Description:
--*/
VMBUS_CHANNEL*
GetChannelFromRelId(
- UINT32 relId
+ u32 relId
)
{
VMBUS_CHANNEL* channel;
@@ -294,7 +294,7 @@ VmbusProcessChannelEvent(
)
{
VMBUS_CHANNEL* channel;
- UINT32 relId = (UINT32)(ULONG_PTR)context;
+ u32 relId = (u32)(ULONG_PTR)context;
ASSERT(relId > 0);
@@ -333,7 +333,7 @@ VmbusOnEvents(
int maxdword = MAX_NUM_CHANNELS_SUPPORTED >> 5;
int bit;
int relid;
- UINT32* recvInterruptPage = gVmbusConnection.RecvInterruptPage;
+ u32* recvInterruptPage = gVmbusConnection.RecvInterruptPage;
//VMBUS_CHANNEL_MESSAGE* receiveMsg;
DPRINT_ENTER(VMBUS);
@@ -393,7 +393,7 @@ VmbusPostMessage(
HV_CONNECTION_ID connId;
- connId.AsUINT32 =0;
+ connId.Asu32 =0;
connId.u.Id = VMBUS_MESSAGE_CONNECTION_ID;
ret = HvPostMessage(
connId,
@@ -414,14 +414,14 @@ Description:
--*/
int
-VmbusSetEvent(UINT32 childRelId)
+VmbusSetEvent(u32 childRelId)
{
int ret=0;
DPRINT_ENTER(VMBUS);
- // Each UINT32 represents 32 channels
- BitSet((UINT32*)gVmbusConnection.SendInterruptPage + (childRelId >> 5), childRelId & 31);
+ // Each u32 represents 32 channels
+ BitSet((u32*)gVmbusConnection.SendInterruptPage + (childRelId >> 5), childRelId & 31);
ret = HvSignalEvent();
DPRINT_EXIT(VMBUS);